@@ -1,17 +1,12 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2021 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
 
 """
 ----------------
@@ -27,19 +22,13 @@ Lark already `supports loading grammars
 <https://lark-parser.readthedocs.io/en/latest/nearley.html>`_
 from `nearley.js <https://nearley.js.org/>`_, so you may not have to write
 your own at all.
-
-Note that as Lark is at version 0.x, this module *may* break API compatibility
-in minor releases if supporting the latest version of Lark would otherwise be
-infeasible.  We may also be quite aggressive in bumping the minimum version of
-Lark, unless someone volunteers to either fund or do the maintenance.
 """
 
-from inspect import getfullargspec
+from inspect import signature
 from typing import Dict, Optional
 
-import attr
 import lark
-from lark.grammar import NonTerminal, Terminal  # type: ignore
+from lark.grammar import NonTerminal, Terminal
 
 from hypothesis import strategies as st
 from hypothesis.errors import InvalidArgument
@@ -50,20 +39,6 @@ from hypothesis.strategies._internal.utils import cacheable, defines_strategy
 __all__ = ["from_lark"]
 
 
-@attr.s()
-class DrawState:
-    """Tracks state of a single draw from a lark grammar.
-
-    Currently just wraps a list of tokens that will be emitted at the
-    end, but as we support more sophisticated parsers this will need
-    to track more state for e.g. indentation level.
-    """
-
-    # The text output so far as a list of string tokens resulting from
-    # each draw to a non-terminal.
-    result = attr.ib(default=attr.Factory(list))
-
-
 def get_terminal_names(terminals, rules, ignore_names):
     """Get names of all terminals in the grammar.
 
@@ -95,7 +70,7 @@ class LarkStrategy(st.SearchStrategy):
         # This is a total hack, but working around the changes is a nicer user
         # experience than breaking for anyone who doesn't instantly update their
         # installation of Lark alongside Hypothesis.
-        compile_args = getfullargspec(grammar.grammar.compile).args
+        compile_args = signature(grammar.grammar.compile).parameters
         if "terminals_to_keep" in compile_args:
             terminals, rules, ignore_names = grammar.grammar.compile(start, ())
         elif "start" in compile_args:  # pragma: no cover
@@ -148,10 +123,10 @@ class LarkStrategy(st.SearchStrategy):
         self.__rule_labels = {}
 
     def do_draw(self, data):
-        state = DrawState()
+        state = []
         start = data.draw(self.start)
         self.draw_symbol(data, start, state)
-        return "".join(state.result)
+        return "".join(state)
 
     def rule_label(self, name):
         try:
@@ -171,8 +146,8 @@ class LarkStrategy(st.SearchStrategy):
                     "use of %%declare unless you pass `explicit`, a dict of "
                     'names-to-strategies, such as `{%r: st.just("")}`'
                     % (symbol.name, symbol.name)
-                )
-            draw_state.result.append(data.draw(strategy))
+                ) from None
+            draw_state.append(data.draw(strategy))
         else:
             assert isinstance(symbol, NonTerminal)
             data.start_example(self.rule_label(symbol.name))
@@ -183,7 +158,7 @@ class LarkStrategy(st.SearchStrategy):
             data.stop_example()
 
     def gen_ignore(self, data, draw_state):
-        if self.ignored_symbols and data.draw_bits(2) == 3:
+        if self.ignored_symbols and data.draw_boolean(1 / 4):
             emit = data.draw(st.sampled_from(self.ignored_symbols))
             self.draw_symbol(data, emit, draw_state)
 
